withAny abstract method

QueryBuilder withAny(
  1. Type a, [
  2. Type? b,
  3. Type? c,
  4. Type? d,
  5. Type? e,
  6. Type? f,
  7. Type? g,
  8. Type? h,
  9. Type? i,
  10. Type? j,
])

At least one of the listed components must be present. Each call is its own group and every group must be satisfied, so .withAny(A, B).withAny(C, D) means "(A or B) and (C or D)", not "(A or B or C or D)".

Implementation

QueryBuilder withAny(
  Type a, [
  Type? b,
  Type? c,
  Type? d,
  Type? e,
  Type? f,
  Type? g,
  Type? h,
  Type? i,
  Type? j,
]);