withAny abstract method
At least one of the listed components must be present. Each call is
its own group and every group must be satisfied, so
.withAny(A, B).withAny(C, D) means "(A or B) and (C or D)", not
"(A or B or C or D)".
Implementation
QueryBuilder withAny(
Type a, [
Type? b,
Type? c,
Type? d,
Type? e,
Type? f,
Type? g,
Type? h,
Type? i,
Type? j,
]);